[PATCH] D23787: Add builder for clang extra tools Sphinx docs

Alexander Kornienko via cfe-commits cfe-commits at lists.llvm.org
Tue Aug 23 04:44:50 PDT 2016


alexfh updated this revision to Diff 68967.
alexfh added a comment.

- Set proper working directory and build step name for clang extra tools SVN checkout.


https://reviews.llvm.org/D23787

Files:
  buildbot/osuosl/master/config/builders.py
  zorg/buildbot/builders/SphinxDocsBuilder.py

Index: buildbot/osuosl/master/config/builders.py
===================================================================
--- buildbot/osuosl/master/config/builders.py
+++ buildbot/osuosl/master/config/builders.py
@@ -1140,6 +1140,13 @@
                'category' : 'clang'
              },
              {
+               'name':"clang-tools-sphinx-docs",
+               'slavenames':["gribozavr4"],
+               'builddir':"clang-tools-sphinx-docs",
+               'factory': SphinxDocsBuilder.getSphinxDocsBuildFactory(clang_tools_html=True),
+               'category' : 'clang'
+             },
+             {
                'name':"lld-sphinx-docs",
                'slavenames':["gribozavr4"],
                'builddir':"lld-sphinx-docs",


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D23787.68967.patch
Type: text/x-patch
Size: 3336 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/cfe-commits/attachments/20160823/fdc50a67/attachment.bin>


More information about the cfe-commits mailing list
Index: zorg/buildbot/builders/SphinxDocsBuilder.py
===================================================================
--- zorg/buildbot/builders/SphinxDocsBuilder.py
+++ zorg/buildbot/builders/SphinxDocsBuilder.py
@@ -6,18 +6,20 @@
 from zorg.buildbot.commands.NinjaCommand import NinjaCommand
 
 def getSphinxDocsBuildFactory(
-        llvm_html   = False, # Build LLVM HTML documentation
-        llvm_man    = False, # Build LLVM man pages
-        clang_html  = False, # Build Clang HTML documentation
-        lld_html    = False, # Build LLD HTML documentation
-        libcxx_html = False  # Build Libc++ HTML documentation
+        llvm_html         = False, # Build LLVM HTML documentation
+        llvm_man          = False, # Build LLVM man pages
+        clang_html        = False, # Build Clang HTML documentation
+        clang_tools_html  = False, # Build Clang Extra Tools HTML documentation
+        lld_html          = False, # Build LLD HTML documentation
+        libcxx_html       = False  # Build Libc++ HTML documentation
         ):
 
     f = buildbot.process.factory.BuildFactory()
 
     llvm_srcdir = 'llvm/src'
     llvm_objdir = 'llvm/build'
     clang_srcdir = llvm_srcdir + '/tools/clang'
+    clang_tools_srcdir = llvm_srcdir + '/tools/clang/tools/extra'
     lld_srcdir = llvm_srcdir + '/tools/lld'
     libcxx_srcdir = llvm_srcdir + '/projects/libcxx'
     libcxxabi_srcdir = llvm_srcdir + '/projects/libcxxabi'
@@ -37,6 +39,13 @@
                       defaultBranch='trunk',
                       workdir=clang_srcdir))
 
+    if clang_tools_html:
+        f.addStep(SVN(name='svn-clang-tools',
+                      mode='update',
+                      baseURL='http://llvm.org/svn/llvm-project/clang-tools-extra/',
+                      defaultBranch='trunk',
+                      workdir=clang_tools_srcdir))
+
     if lld_html:
         f.addStep(SVN(name='svn-lld',
                       mode='update',
@@ -99,6 +108,14 @@
                                targets=['docs-clang-html']
                               ))
 
+    if clang_tools_html:
+        f.addStep(NinjaCommand(name="docs-clang-tools-html",
+                               haltOnFailure=True,
+                               description=["Build Clang Extra Tools Sphinx HTML documentation"],
+                               workdir=llvm_objdir,
+                               targets=['docs-clang-tools-html']
+                              ))
+
     if lld_html:
         f.addStep(NinjaCommand(name="docs-lld-html",
                                haltOnFailure=True,